==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/sr-CS/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Aktivan',
    'allow'  				=> 'Dopustiti',
    'checkedout'  			=> 'Imovina',
    'created_at' 			=> 'Kreiran',
    'createuser' 			=> 'Kreiraj korisnika',
    'deny'  				=> 'Zabrani',
    'email'      			=> 'Email',
    'employee_num'      	=> 'Broj zaposlenog.',
    'first_name' 			=> 'Ime',
    'groupnotes'			=> 'Odaberite grupu koju ćete dodeliti korisniku, ne zaboravite da korisnik preuzima dozvole grupe kojoj je dodeljen.',
    'id'         			=> 'Id',
    'inherit'  				=> 'Naslediti',
    'job' 					=> 'Naziv posla',
    'last_login'  			=> 'Poslednja prijava',
    'last_name'  			=> 'Prezime',
    'location'  			=> 'Lokacija',
    'lock_passwords'		=> 'Na ovoj instalaciji ne mogu se mijenjati podaci za prijavu.',
    'manager' 				=> 'Menadžer',
    'managed_locations'     => 'Managed Locations',
    'name' 					=> 'Ime',
    'notes'                 => 'Zabeleške',
    'password_confirm' 		=> 'Potvrdi lozinku',
    'password' 				=> 'Lozinka',
    'phone'  				=> 'Telefon',
    'show_current'          => 'Prikaži trenutne korisnike',
    'show_deleted'          => 'Prikaži izbrisane korisnike',
    'title' 				=> 'Title',
	'to_restore_them'		=> 'to restore them.',
    'updateuser' 			=> 'Ažuriranje korisnika',
    'username' 				=> 'Korisničko ime',
	'user_deleted_text' 	=> 'Ovaj je korisnik označen kao izbrisan.',
    'username_note' 		=> '(This is used for Active Directory binding only, not for login.)',
    'cloneuser'             => 'Kloniraj korisnika',
    'viewusers' 			=> 'Prikaži korisnike',
);

==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/sr-CS/admin/users/table.php <==
<?php

return array(
    'activated'  			=> 'Aktivan',
    'allow'  				=> 'Dopustiti',
    'checkedout'  			=> 'Imovina',
    'created_at' 			=> 'Kreiran',
    'createuser' 			=> 'Kreiraj korisnika',
    'deny'  				=> 'Zabrani',
    'email'      			=> 'Email',
    'employee_num'      	=> 'Broj zaposlenog.',
    'first_name' 			=> 'Ime',
    'groupnotes'			=> 'Izaberite grupu koju želite da dodelite korisniku, zapamtite da korisnik preuzima dozvole grupe koja mu je dodeljena. Koristite ctrl+klik (ili cmd+klik na MacOS-u) da poništite izbor grupa.',
    'id'         			=> 'Id',
    'inherit'  				=> 'Naslediti',
    'job' 					=> 'Naziv posla',
    'last_login'  			=> 'Poslednja prijava',
    'last_name'  			=> 'Prezime',
    'location'  			=> 'Lokacija',
    'lock_passwords'		=> 'Na ovoj instalaciji ne mogu se mijenjati podaci za prijavu.',
    'manager' 				=> 'Menadžer',
    'managed_locations'     => 'Managed Locations',
    'name' 					=> 'Ime',
    'nogroup'               => 'Nijedna grupa još uvek nije napravljena. Da je dodate, posetite: ',
    'notes'                 => 'Zabeleške',
    'password_confirm' 		=> 'Potvrdi lozinku',
    'password' 				=> 'Lozinka',
    'phone'  				=> 'Telefon',
    'show_current'          => 'Prikaži trenutne korisnike',
    'show_deleted'          => 'Prikaži izbrisane korisnike',
    'title' 				=> 'Title',
	'to_restore_them'		=> 'to restore them.',
    'total_assets_cost'     => "Ukupni troškovi imovine",
    'updateuser' 			=> 'Ažuriranje korisnika',
    'username' 				=> 'Korisničko ime',
	'user_deleted_text' 	=> 'Ovaj je korisnik označen kao izbrisan.',
    'username_note' 		=> '(This is used for Active Directory binding only, not for login.)',
    'cloneuser'             => 'Kloniraj korisnika',
    'viewusers' 			=> 'Prikaži korisnike',
);
